# -------------------------------------------------
# detecting population density trends
# -------------------------------------------------

#replace *** with local directory

# open packages
library(lme4)

# -------------------
# Select model to use
# -------------------

#
# Patersons Terrace | Large females | November + December counts
#

set.seed(20190805)

# read in data
pattAF <- read.csv('***/Schori_et_al_2020_PLOSOne_dataset/detecting-population-density-trends/Patersons_AF_NovDec_dat.csv')

# model selection
mod <- glmer(count ~ Year_t + (1|Transect) + (1|Visit_season) + (1|Individual), family = poisson, data = pattAF)

mod1 <- glmer(count ~ Year_t + (1|Transect) + (1|Visit_season), family = poisson, data = pattAF)

AIC(mod, mod1)
anova(mod, mod1)
# No sig diff in models, but mod1 has lower AIC

#
# Patersons Terrace | Total population | February counts
#

set.seed(20190805)

# read in data
pat <- read.csv('***/Schori_et_al_2020_PLOSOne_dataset/detecting-population-density-trends/Patersons_Tp_Feb_dat.csv')

# model selection
mod <- glmer(count ~ Year_t + (1|Transect) + (1|Visit_season) + (1|Individual), family = poisson, data = pat)

mod1 <- glmer(count ~ Year_t + (1|Transect) + (1|Visit_season), family = poisson, data = pat)

AIC(mod, mod1)
anova(mod, mod1)

# mod is sig diff to mod1, + lower AIC

#
# Snowy River | Adult Females | November and December counts
#

set.seed(20190805)

# read in data
snowAF <- read.csv('***/Schori_et_al_2020_PLOSOne_dataset/detecting-population-density-trends/Snowy_AF_NovDec_dat.csv')

# model selection
mod <- glmer(count ~ Year_t + (1|Transect) + (1|Visit_season) + (1|Individual), family = poisson, data = snowAF)

mod1 <- glmer(count ~ Year_t + (1|Transect) + (1|Visit_season), family = poisson, data = snowAF)

AIC(mod, mod1)
anova(mod, mod1)
# No sig diff in models, but mod has lower AIC

#
# Snowy River | Total population | February counts
#

set.seed(20190805)

# read in data
snow <- read.csv('***/Schori_et_al_2020_PLOSOne_dataset/detecting-population-density-trends/Snowy_Tp_Feb_dat.csv')

# model selection
mod <- glmer(count ~ Year_t + (1|Transect) + (1|Visit_season) + (1|Individual), family = poisson, data = snow)

mod1 <- glmer(count ~ Year_t + (1|Transect) + (1|Visit_season), family = poisson, data = snow)

AIC(mod, mod1)
anova(mod, mod1)
# No sig diff in models, but mod1 has lower AIC

# -------------------------
# prepare to run simulation
# -------------------------

# number of simulations to run
nsim <- 1000

# number of transects
transects <- seq(3, 40, by=1)

#number of visits
visits <- seq(2, 25, by=1)

# storing results
powersummary <- data.frame(matrix(NA, ncol = 25, nrow = 40))

newdata <- data.frame()

pval <- list()

# ---------------
# run simulations
# ---------------

#
# Model that does not include an 'individual' parameter
#

for (t in transects){ 
  for (v in visits) { 

   newdata <- expand.grid(Visit_season = as.factor(1:v), 
                           Transect = as.factor(1:t),
                           Year_t = c(0,1))          #Year_t = c(0,1,2)) for Patersons Terrace data

#create 'nsim' replicates of results using the new data frame
   simdat <- simulate(mod1, nsim=nsim, newdata=newdata, re.form=~0, allow.new.levels = TRUE, family=poisson())

    for(j in 1:nsim){

#print the number of the simulation
      print(j)

#using a the results of simulation j, create a data frame with response, transect, visits and         year variables
      sdat <- data.frame(response=simdat[,j], newdata)

# if all the responses are 0, return p value of 1
      if (sum(sdat$response == 0) == length(sdat$response)) { 
        pval[j] <- 1

#otherwise, fit the model to the new data
      } else { 
        smod <- try(glmer(response ~ Year_t + (1|Transect) + 
                            (1|Visit_season), family = poisson, data = sdat))

#if the model returns an error (cannot be fit), the return a p vlaue of 1
         if (class(smod)[1] == "try-error"){
          pval[j] <- 1 

#otherwise, return the p-value for the fixed effect "Year"
        } else {
          pval[j] <- coef(summary(smod))["Year_t","Pr(>|z|)"]
       }
      }}
#calculate the power for each number of transects and visits
    powersummary[t,v] <- sum(pval < 0.05)/nsim    

  }}

#
# Model that does include an 'individual' parameter
#

for (t in transects){ 
  for (v in visits) { 

    newdata <- expand.grid(Visit_season = as.factor(1:v), 
                           Transect = as.factor(1:t),
                           Year_t = c(0,1))          #Year_t = c(0,1,2)) for Patersons Terrace data
    newdata$Individual <- as.factor(1:nrow(newdata))

#create 'nsim' replicates of results using the new data frame
    simdat <- simulate(mod1, nsim=nsim, newdata=newdata, re.form=~0, allow.new.levels = TRUE, family=poisson())

    for(j in 1:nsim){

#print the number of the simulation
      print(j)

#using a the results of simulation j, create a data frame with response, transect, visits and         year variables
      sdat <- data.frame(response=simdat[,j], newdata)

# if all the responses are 0, return p value of 1
      if (sum(sdat$response == 0) == length(sdat$response)) { 
        pval[j] <- 1

#otherwise, fit the model to the new data
      } else { 
        smod <- try(glmer(response ~ Year_t + (1|Transect) + 
                            (1|Visit_season) + (1|Individual), family = poisson, data = sdat))

#if the model returns an error (cannot be fit), the return a p vlaue of 1
        if (class(smod)[1] == "try-error"){
          pval[j] <- 1 

#otherwise, return the p-value for the fixed effect "Year"
        } else {
          pval[j] <- coef(summary(smod))["Year_t","Pr(>|z|)"]
        }
      }}
#calculate the power for each number of transects and visits
    powersummary[t,v] <- sum(pval < 0.05)/nsim    

  }}