# --------------------
# Index of Dispersion
# --------------------

#replace *** with local directory

library(plyr); library(dplyr)

# -----------------
# Season 1: Plots
# -----------------

plots1 <- read.csv('***/Schori_et_al_2020_PLOSOne_dataset/index-of-dispersion/PatplotsS1.csv', header = TRUE)

#make sampling session a factor
plots1$Visit_season <- factor(plots1$Visit_season)

#put the months in the right order
plots1$Month <- factor(plots1$Month, levels=c("Nov", "Dec","Jan", "Feb", "Mar")) 

#make length a numeric
plots1$Body_length <- as.numeric(as.character(plots1$Body_length))

#summarise data to get the number of individuals counted per plot group (100m)
plots1_density100 <- plots1 %>%
  group_by(Month, Visit_season, Plot) %>%
  summarise(total = sum(Sex != '0')) 
plots1_density100$Name <- "Plot_S1_100"
plots1_density100$Transect <- NA
plots1_density100$Method <- "Plot"
plots1_density100$Season <- 1

#summarise data to get the number of individuals counted per sampling session (300m)
plots1_density300 <- plots1 %>%
  group_by(Month, Visit_season) %>%
  summarise(total = sum(Sex != '0'))
plots1_density300$Name <- "Plot_S1_300"
plots1_density300$Method <- "Plot"
plots1_density300$Season <- 1


# --------------------
# Season 1: Transects
# --------------------

trans1 <- read.csv('***/Schori_et_al_2020_PLOSOne_dataset/index-of-dispersion/PattransS1.csv', header = TRUE)

#make sampling session a factor
trans1$Visit_season <- factor(trans1$Visit_season)

#put the months in the right order
trans1$Month <- factor(trans1$Month, levels=c("Nov", "Dec","Jan", "Feb", "Mar")) 

#make length a numeric
trans1$Body_length <- as.numeric(as.character(trans1$Body_length))

#summarise data to get the number of individuals counted per plot group (100m)
trans1_density100 <- trans1 %>%
  group_by(Month, Visit_season, Transect) %>%
  summarise(total = sum(Sex != '0')) 
trans1_density100$Name <- "Transect_S1_100"
trans1_density100$Plot <- NA
trans1_density100$Method <- "Transect"
trans1_density100$Season <- 1

#summarise data to get the number of individuals counted per sampling session (300m)
trans1_density300 <- trans1 %>%
  group_by(Month, Visit_season) %>%
  summarise(total = sum(Sex != '0'))
trans1_density300$Name <- "Transect_S1_300"
trans1_density300$Method <- "Transect"
trans1_density300$Season <- 1

# ----------------
#Season 2: Plots
# ----------------

plots2 <- read.csv('***/Schori_et_al_2020_PLOSOne_dataset/index-of-dispersion/PatplotsS2.csv', header = TRUE)

#make sampling session a factor
plots2$Visit_season <- factor(plots2$Visit_season)

#put the months in the right order
plots2$Month <- factor(plots2$Month, levels=c("Nov", "Dec","Jan", "Feb", "Mar")) 

#summarise data to get the number of individuals counted per plot group (100m)
plots2_density100 <- plots2 %>%
  group_by(Month, Visit_season, Plot) %>%
  summarise(total = sum(Sex != '0')) 
plots2_density100$Name <- "Plot_S2_100"
plots2_density100$Transect <- NA
plots2_density100$Method <- "Plot"
plots2_density100$Season <- 2

#summarise data to get the number of individuals counted per sampling session (300m)
plots2_density300 <- plots2 %>%
  group_by(Month, Visit_season) %>%
  summarise(total = sum(Sex != '0'))
plots2_density300$Name <- "Plot_S2_300"
plots2_density300$Method <- "Plot"
plots2_density300$Season <- 2

# --------------------
# Season 2: Transects
# --------------------

trans2 <- read.csv('***/Schori_et_al_2020_PLOSOne_dataset/index-of-dispersion/PattransS2.csv', header = TRUE)

#make sampling session a factor
trans2$Visit_season <- factor(trans2$Visit_season)

#put the months in the right order
trans2$Month <- factor(trans2$Month, levels=c("Nov", "Dec","Jan", "Feb", "Mar")) 

#make length a numeric
#trans2$Length <- as.numeric(as.character(trans2$Length))

#summarise data to get the number of individuals counted per plot group (100m)
trans2_density100 <- trans2 %>%
  group_by(Month, Visit_season, Transect) %>%
  summarise(total = sum(Sex != '0')) 
trans2_density100$Name <- "Transect_S2_300"
trans2_density100$Plot <- NA
trans2_density100$Method <- "Transect"
trans2_density100$Season <- 2

#summarise data to get the number of individuals counted per sampling session (300m)
trans2_density300 <- trans2 %>%
  group_by(Month, Visit_season) %>%
  summarise(total = sum(Sex != '0'))
trans2_density300$Name <- "Transect_S2_300"
trans2_density300$Method <- "Transect"
trans2_density300$Season <- 2

#----------------
# Season 3: Plots
# ---------------

plots3 <- read.csv('***/Schori_et_al_2020_PLOSOne_dataset/index-of-dispersion/PatplotsS3.csv', header = TRUE)

#make sampling session a factor
plots3$Visit_season <- factor(plots3$Visit_season)

#put the months in the right order
plots3$Month <- factor(plots3$Month, levels=c("Nov", "Dec","Jan", "Feb", "Mar")) 

#summarise data to get the number of individuals counted per plot group (100m)
plots3_density100 <- plots3 %>%
  group_by(Month, Visit_season, Plot) %>%
  summarise(total = sum(Sex != '0')) 
plots3_density100$Name <- "Plot_S3_100"
plots3_density100$Transect <- NA
plots3_density100$Method <- "Plot"
plots3_density100$Season <- 3

#summarise data to get the number of individuals counted per sampling session (300m)
plots3_density300 <- plots3 %>%
  group_by(Month, Visit_season) %>%
  summarise(total = sum(Sex != '0'))
plots3_density300$Name <- "Plot_S3_300"
plots3_density300$Method <- "Plot"
plots3_density300$Season <- 3

# -------------------
# Season 3: Transects
# -------------------

trans3 <- read.csv('***/Schori_et_al_2020_PLOSOne_dataset/index-of-dispersion/PattransS3.csv', header = TRUE)

#make sampling session a factor
trans3$Visit_season <- factor(trans3$Visit_season)

#put the months in the right order
trans3$Month <- factor(trans3$Month, levels=c("Nov", "Dec","Jan", "Feb", "Mar")) 

#summarise data to get the number of individuals counted per plot group (100m)
trans3_density100 <- trans3 %>%
  group_by(Month, Visit_season, Transect) %>%
  summarise(total = sum(Sex != '0')) 
trans3_density100$Name <- "Transect_S3_100"
trans3_density100$Plot <- NA
trans3_density100$Method <- "Transect"
trans3_density100$Season <- 3

#summarise data to get the number of individuals counted per sampling session (300m)
trans3_density300 <- trans3 %>%
  group_by(Month, Visit_season) %>%
  summarise(total = sum(Sex != '0'))
trans3_density300$Name <- "Transect_S3_300"
trans3_density300$Method <- "Transect"
trans3_density300$Season <- 3

# --------------------------------------------
# combine the datasets into a single dataframe ----
# ---------------------------------------------

density_100_FULL <- rbind(plots1_density100, plots2_density100,plots3_density100, trans1_density100, trans2_density100, trans3_density100)

density_300_FULL <- rbind(plots1_density300, plots2_density300,plots3_density300, trans1_density300, trans2_density300, trans3_density300)

# ------------------------------
# SNOWY S2 (first year at Snowy) ----
# ------------------------------

snow2 <- read.csv('***/Schori_et_al_2020_PLOSOne_dataset/index-of-dispersion/SnowyS2.csv', header = TRUE)

#make sampling session a factor
snow2$Visit_season <- factor(snow2$Visit_season)

#put the months in the right order
snow2$Month <- factor(snow2$Month, levels=c("Nov", "Dec","Jan", "Feb", "Mar")) 

#summarise data to get the number of individuals counted per plot group (100m)
snow2_density100 <- snow2 %>%
  group_by(Month, Visit_season, Transect) %>%
  summarise(total = sum(Sex != '0')) 
snow2_density100$Name <- "Snow_S2_100"
snow2_density100$Plot <- NA
snow2_density100$Method <- "SnowyT"
snow2_density100$Season <- 2

# -------------------------------
# SNOWY S3 (second year at Snowy) ----
# -------------------------------

snow3 <- read.csv('***/Schori_et_al_2020_PLOSOne_dataset/index-of-dispersion/SnowyS3.csv', header = TRUE)

#make sampling session a factor
snow3$Visit_season <- factor(snow3$Visit_season)

#put the months in the right order
snow3$Month <- factor(snow3$Month, levels=c("Nov", "Dec","Jan", "Feb", "Mar")) 

#summarise data to get the number of individuals counted per plot group (100m)
snow3_density100 <- snow3 %>%
  group_by(Month, Visit_season, Transect) %>%
  summarise(total = sum(Sex != '0')) 
snow3_density100$Name <- "Snow_S3_100"
snow3_density100$Plot <- NA
snow3_density100$Method <- "SnowyT"
snow3_density100$Season <- 3

# -----------------------------
# Step 1: Generate variability estimates for each transects, in each month, for each sampling stretegy, for each season ----
# -----------------------------

#join the datasets together to make a new one
var_data <- rbind (density_100_FULL, snow2_density100, snow3_density100)

#put plot ID and transect ID into the same column 
var_data$Transect <- as.factor(var_data$Transect)
var_data$ID <- ifelse(is.na(var_data$Transect),var_data$Plot, var_data$Transect)

var_data$Month <- as.factor(as.character(var_data$Month))
var_data$Name <- as.factor(as.character(var_data$Name))
var_data$Method <- as.factor(as.character(var_data$Method))
var_data$Season <- as.factor(as.numeric(var_data$Season))

# ------------------------------
# generate the mean and standard deviation for each of the groups in the dataframe
# ------------------------------

library(reshape2)

var_data_output<- ddply(var_data, c("Method", "Name", "Season", "Month", "ID"), summarise,
                        mean = mean(total), sd = sd(total),
                        sem = sd(total)/sqrt(length(total)),
                        var = var(total),
                        D = var(total)/mean(total))
var_data_output$Log_D <- log(var_data_output$D)

# drop season 1 because Snowy River data is missing
var_data_output <- var_data_output[var_data_output$Season != '1',]
var_data_output <- droplevels(var_data_output)

# --------------
# write model
# --------------

library(lme4)
library(lmerTest)

# model 1

mod1 <- lmer(D ~ Method + (1|ID), data = var_data_output, REML = T)

# look at output
summary(mod1)
anova(mod1)
difflsmeans(mod1, test.effs = "Method")

#check for normal residuals
hist(residuals(mod1),col="darkgray")

#check for homoscedastic residulas
plot(fitted(mod1),residuals(mod1))
difflsmeans(mod1, test.effs = "Method")

# ------------------------------------
# try re-running the analysis after removing the outliers and see what the results are 
# ------------------------------------

# remove outliers from data
dat_no_out <- var_data_output[var_data_output$D < 3,]

# model 2
mod2 <- lmer(D ~ Method + Month + (1|Season) + (1|ID), data = dat_no_out, REML = T)

# look at output
summary(mod2)
anova(mod2)
difflsmeans(mod2, test.effs = "Method")

#check for normal residuals
hist(residuals(mod2),col="darkgray")

#check for homoscedastic residulas
plot(fitted(mod2),residuals(mod2))

# no difference in findings from results, stick with model1 that contains all the data points

# -----------------
# post-hoc analysis
# -----------------

library(ggplot2); library(multcomp)

summary(glht(mod2, linfct = mcp(Month = "Tukey")))

ggplot(var_data_output, aes(y = D, x= Method)) + 
  geom_boxplot() + 
  #facet_wrap(~ Month) +
  theme_bw()+
  ylab("Index of dispersion") + 
  #geom_text(data = label.df  label = "*") +
  scale_x_discrete(labels = c('Plot\nPatersons','Transect\nPatersons','Transect\nSnowy'))

